@@ -34,7 +34,7 @@ bool Methods::scrConnect(void)
 	const char *script = getValue(NULL);
 	char dbuf[65];
 	char nbuf[256];
-	timeslot_t limit = Bayonne::ts_count;
+	timeslot_t limit = 0;
 	const char *cp = getKeyword("limit");
 	Line *sel = getLine();
 	Symbol *sym = getKeysymbol("session", 16);
@@ -104,12 +104,14 @@ bool Methods::scrConnect(void)
 
 	if(!sel && proto)
 	{
-		child = proto->getIdle();
+		if(!limit || proto->getAvail() >= limit)
+			child = proto->getIdle();
 		goto any;
 	}
 	else if(!sel)
 	{
-		child = trunk->getIdle();
+		if(!limit || trunk->getAvail() >= limit)
+			child = trunk->getIdle();
 		goto any;
 	}
 
@@ -175,6 +177,9 @@ bool Methods::scrConnect(void)
 			if(!span)	
 				continue;
 
+			if(limit && span->getAvail() < limit)
+				continue;
+
 			pos = span->getFirst();
 			count = span->getCount();
 			while(count--)
