@@ -397,7 +397,7 @@ bool Bayonne::matchDigits(const char *digits, const char *match, bool partial)
 		digits += (len - dlen);
 	}
 
-	while(*match)
+	while(*match && *digits)
 	{
 		inc = true;
 		switch(*match)
@@ -434,9 +434,12 @@ bool Bayonne::matchDigits(const char *digits, const char *match, bool partial)
 			++digits;
 		++match;	
 	}
-	if(*digits)
+	if(*match && !*digits)
 		return partial;
 
+	if(*match && *digits)
+		return false;
+
 	return true;
 }
 
