@@ -1059,27 +1059,56 @@ exitkey:
         return enterCommon(event);
 }
 
+void BayonneSession::renameRecord(void)
+{
+        const char *path = audio.getFilename(state.audio.list[0], true);
+
+        if(!path || !state.audio.list[1])
+                return;
+
+        rename(path, state.audio.list[1]);
+        state.audio.list[1] = NULL;
+}
+
 bool BayonneSession::stateRecord(Event *event)
 {
 	char evtmsg[65];
 	char key;
 	time_t now;
+	const char *path;
+        char *buffer = (char *)&state.audio.list[2];
 
 	switch(event->id)
 	{
 	case ENTER_STATE:
 		time(&audiotimer);
+                if(!state.audio.list[1])
+                        break;
+                path = audio.getFilename(state.audio.list[1], true);
+                if(path)
+                {
+                        setString(buffer, 256, path);
+                        state.audio.list[1] = buffer;
+                }
+                else
+                        state.audio.list[1] = NULL;
 		break;
 	case STOP_DISCONNECT:
 	case STOP_SCRIPT:
 	case CALL_DISCONNECT:
 	case CALL_FAILURE:
 		time(&now);
-		if(now - audiotimer > 3)
+		if(now - audiotimer > 3 || state.audio.total < 30000)
+		{
+			renameRecord();
 			break;
-		if(state.audio.total < 30000)
-			break;
-		remove(state.audio.list[0]);
+		}
+                path = audio.getFilename(state.audio.list[0], true);
+                remove(path);
+		state.audio.list[1] = NULL;
+		break;
+	case AUDIO_IDLE:
+		renameRecord();
 	}
 
         if(enterRecord(event))
@@ -1123,6 +1152,7 @@ bool BayonneSession::stateRecord(Event *event)
 		key = getChar(event->dtmf.digit);
 		if(state.audio.exit && strchr(state.audio.exit, key))
 		{
+			renameRecord();
 			snprintf(evtmsg, sizeof(evtmsg), "exitkey:%c", key);
 			if(scriptEvent(evtmsg))
 			{
@@ -1148,6 +1178,7 @@ exitkey:
 			*dtmf_digits = key;
 			dtmf_digits[1] = 0;
 			digit_count = 1;
+			renameRecord();
 			advance();
 			setRunning();
 			return true;
