@@ -1027,6 +1027,8 @@ bool Methods::scrRecord(void)
         }
 
 	state.audio.list[0] = getValue(NULL);
+	state.audio.list[1] = getValue(NULL);
+	state.audio.list[2] = NULL;
 
 	state.audio.mode = Audio::modeCreate;
 	if(audio.offset)
@@ -1075,6 +1077,8 @@ bool Methods::scrAppend(void)
         }
 
 	state.audio.list[0] = getValue(NULL);
+	state.audio.list[1] = getValue(NULL);
+	state.audio.list[2] = NULL;
 	state.audio.mode = Audio::modeAppend;
 
 	setState(STATE_RECORD);
