@@ -147,6 +147,7 @@ static void loading(void)
 
 	BayonneSysexec::allocate(keypaths.getLast("libexec"), bs, pri,
 		keypaths.getLast("modexec"));
+
 #endif
         cp = keyserver.getLast("language");
         if(cp && (strlen(cp) == 2 || cp[2] == '_'))  
@@ -512,6 +513,10 @@ int main(int argc, char **argv)
 
 	keyserver.setValue("argv0", argv0);
 
+#ifdef	HAVE_LIBEXEC
+	runtime.setValue("definitions", "libexec.def");
+#endif
+
 	if(argc == 2)
 	{
 		cp = argv[1];
@@ -602,6 +607,8 @@ int main(int argc, char **argv)
                         stop(-1);
                 }
         }
+	else
+		Process::setGroup(keyserver.getLast("group"));
 
         cp = keyengine.getLast("trunking");
         if(cp && !stricmp(cp, "autodetect"))
