@@ -11,7 +11,7 @@ if(strlen($libexec) > 0) {
 require_once("libexec.php");
 $TGI = &new Libexec;
 $TGI->print_output("PHP LIBEXEC STARTED\n");
-$result = $TGI->play_prompt("&number 123");
+$result = $TGI->speak_phrase("&number 123");
 $TGI->send_result($result);
 $file1 = $TGI->get_pathname("tmp:edit");
 $TGI->print_output("P1 $file1\n");
